@@ -7,12 +7,11 @@
 #include <glib-object.h>
 
 G_BEGIN_DECLS
-
 /* enumerations from "rsvg.h" */
-
 GType rsvg_error_get_type (void);
 #define RSVG_TYPE_ERROR (rsvg_error_get_type())
-
+GType rsvg_handle_flags_get_type (void);
+#define RSVG_TYPE_HANDLE_FLAGS (rsvg_handle_flags_get_type())
 G_END_DECLS
 
 #endif /* __LIBRSVG_ENUM_TYPES_H__ */
